# Table of Contents

- [add-applications](<./add-applications.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Add Applications](<./Add-Applications.md>)
  - [Introduction to Applications](<./Add-Applications/Introduction-to-Applications.md>)
  - [Required Attributes](<./Add-Applications/Required-Attributes.md>)
  - [Collect Application Data](<./Add-Applications/Collect-Application-Data.md>)
  - [Add Applications](<./Add-Applications/Add-Applications.md>)
  - [Scope Applications](<./Add-Applications/Scope-Applications.md>)
  - [Monitor Progress Using Metrics](<./Add-Applications/Monitor-Progress-Using-Metrics.md>)
